# Spuring

**spuring** is a Python CLI for creating folder setup for any kind. Its specialisied to create Python project folders, but you can setup your needs with the toml template file.


This project has been started recently. The prject **has not** reached a release state.



``pip install git+https://github.com/TobiasBaumgarten/spuring.git``